/**
   A Model data structure represents a distinct geometric object (in a Scene). A Model data structure is mainly a list of LineSegment objects. The line segments represent the geometric object as a "wire-frame", that is, the geometric object is drawn as a collection of "edges". This is a fairly simplistic way of doing 3D graphics and we will improve this in a later renderer.

   See
      http://en.wikipedia.org/wiki/Wire-frame_model
   or
      https://www.google.com/search?q=graphics+wireframe&tbm=isch
*/
import java.util.List;
import java.util.LinkedList;
import java.awt.Color;

public class Model
{
   public List<LineSegment> lineSegmentList = new LinkedList<LineSegment>();


   public Model()
   {
   }


   /**
      Duplicate a Model object.
   */
   public Model(Model model1)
   {
      // Copy everything except the list of line segments.
   }//duplicating constructor


   /**
      Add a LineSegment to this model's list of line segments.
   */
   public void addLineSegment(LineSegment ls)
   {
      this.lineSegmentList.add(ls);
   }


   /**
      Set all the vertices in this model to the same color.
   */
   public void setColor(Color c)
   {
      for (LineSegment ls : this.lineSegmentList)
      {
         ls.v[0].setColor(c);
         ls.v[1].setColor(c);
      }
   }


   /**
      Set all the vertices in this model to random colors.
   */
   public void setRandomColors()
   {
      for (LineSegment ls : this.lineSegmentList)
      {
         ls.v[0].setColorRandom();
         ls.v[1].setColorRandom();
      }
   }


   /**
      For debugging.
   */
   public String toString()
   {
      String result = "";
      result += "This Model has " + lineSegmentList.size() + " line segments\n";
      //result = "Printing out this Model's " + lineSegmentList.size() + " Line segments:\n";
      for (LineSegment ls : this.lineSegmentList)
      {
         result += ls.toString();
      }
      //result += "Done printing out Model\n";
      return result;
   }


   /**
      Used for debugging. What this method returns
      depends on the value of the parameter vertexFields.

      The value of vertexFields is treated as a bit field.
      The bits have the following meanings.
        1 => print vertex coordinates
        2 => print r g b values
   */
   public String toString(int vertexFields)
   {
      String result = "";
      result += "This Model has " + lineSegmentList.size() + " line segments\n";
      //result = "Printing out this Model's " + lineSegmentList.size() + " Line segments:\n";
      for (LineSegment ls : this.lineSegmentList)
      {
         result += ls.toString(vertexFields);
      }
      //result += "Done printing out Model\n";
      return result;
   }
}