/**
   Convert line segments from world coordinates to view (camera) coordinates.

   For each Model in a Scene, walk the Model's list of LineSegment objects.
   For each Vertex object in each LineSgement object, use the Scene's view
   matrix to transform the Vertex object from world coordinates to view
   coordinates.
*/

public class P1_World2View extends PipelineStage
{
   /**
      This constructor initializes this object's
      reference to the SceneRender object that
      contains it. This gives this stage access
      to addditional information that might be
      needed to process the Models passed to the
      processModel() method.
   */
   public P1_World2View(SceneRender sceneRender)
   {
      super(sceneRender);
   }


   /**
      For each line segment in the model, transform each
      vertex from world coordinates to view coordinates.
   */
   public Model processModel(Model model)
   {
      Matrix viewMatrix = this.sceneRender.scene.camera.viewMatrix;

      // Transform each line segment in the model's line segment list.
      for (LineSegment ls : model.lineSegmentList)
      {
         ls.v[0] = viewMatrix.times(ls.v[0]); // transform each vertex in the line segment
         ls.v[1] = viewMatrix.times(ls.v[1]);
      }
      return model;
   }
}